"use strict";
/*
* This program and the accompanying materials are made available under the terms of the *
* Eclipse Public License v2.0 which accompanies this distribution, and is available at *
* https://www.eclipse.org/legal/epl-v20.html                                      *
*                                                                                 *
* SPDX-License-Identifier: EPL-2.0                                                *
*                                                                                 *
* Copyright Contributors to the Zowe Project.                                     *
*                                                                                 *
*/
Object.defineProperty(exports, "__esModule", { value: true });
exports.ImsRestClient = void 0;
const imperative_1 = require("@zowe/imperative");
/**
 * Wrapper for invoke IMS API through the RestClient to perform common error
 * handling and checking and resolve promises according to generic types
 * @export
 * @class ImsRestClient
 * @extends {RestClient}
 */
class ImsRestClient extends imperative_1.RestClient {
    /**
     * Use the Zowe logger instead of the imperative logger
     * @return {Logger}
     */
    static get log() {
        if (this.mLogger == null) {
            this.mLogger = imperative_1.Logger.getAppLogger();
        }
        return this.mLogger;
    }
    /**
     * Overridden request method implemented to append hostname, port, and plex headers to all IMS requests.
     */
    request(options) {
        if (options.reqHeaders == null) {
            options.reqHeaders = [];
        }
        // Log the resource and request info
        ImsRestClient.log.debug("\n\nResource: " + options.resource + "\nRequest: " + options.request + "\n");
        const imsSession = this.session;
        if (imsSession.imsConnectHost != null) {
            options.reqHeaders.push({ hostname: imsSession.imsConnectHost });
        }
        if (imsSession.imsConnectPort != null) {
            options.reqHeaders.push({ port: imsSession.imsConnectPort });
        }
        return super.request(options);
    }
    /**
     * Process an error encountered in the rest client
     * @param {IImperativeError} original - the original error automatically built by the abstract rest client
     * @returns {IImperativeError} - the processed error with details added
     */
    processError(original) {
        original.msg = "IMS Operations API Error:\n" + original.msg;
        let details = original.causeErrors;
        try {
            const jsonDetails = JSON.parse(details);
            // if we didn't get an error, make the parsed details part of the error
            details = imperative_1.TextUtils.prettyJson(jsonDetails, undefined, false);
            original.msg += "\n" + details; // add the data string which is the original error
            return original;
        }
        catch (e) {
            // if there's an error, the causeErrors text is not json
            ImsRestClient.log.debug("Encountered an error trying to parse causeErrors as XML  - causeErrors is likely not JSON format");
            original.msg += "\n" + details; // add the data string which is the original error
            return original;
        }
    }
}
exports.ImsRestClient = ImsRestClient;
/**
 * If the API request is successful, this value should be in
 * api_response2 in  the resultsummary object in the response
 */
ImsRestClient.IMS_SUCCESS_RESPONSE_1 = "1024";
/**
 * If the API request is successful, this value should be in
 * api_response2 in  the resultsummary object in the response
 */
ImsRestClient.IMS_SUCCESS_RESPONSE_2 = "0";
//# sourceMappingURL=ImsRestClient.js.map