"use strict";
/*
* This program and the accompanying materials are made available under the terms of the *
* Eclipse Public License v2.0 which accompanies this distribution, and is available at *
* https://www.eclipse.org/legal/epl-v20.html                                      *
*                                                                                 *
* SPDX-License-Identifier: EPL-2.0                                                *
*                                                                                 *
* Copyright Contributors to the Zowe Project.                                     *
*                                                                                 *
*/
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.ImsBaseHandler = void 0;
const imperative_1 = require("@zowe/imperative");
const ImsSessionUtils_1 = require("./ImsSessionUtils");
/**
 * This class is used by the various ims handlers as the base class for their implementation.
 * All handlers should extend this class whenever possible
 */
class ImsBaseHandler {
    /**
     * This will grab the ims profile and create a session before calling the subclass
     * {@link ImsBaseHandler#processWithSession} method.
     *
     * @param {IHandlerParameters} commandParameters Command parameters sent by imperative.
     *
     * @returns {Promise<void>}
     */
    process(commandParameters) {
        return __awaiter(this, void 0, void 0, function* () {
            this.params = commandParameters;
            const session = yield ImsSessionUtils_1.ImsSessionUtils.createSessCfgFromArgs(commandParameters.arguments, true, commandParameters);
            const response = yield this.processWithSession(commandParameters, session);
            commandParameters.response.progress.endBar(); // end any progress bars
            // Return as an object when using --response-format-json
            commandParameters.response.data.setObj(response);
        });
    }
    /**
     * Check return codes for messages in case we don't receive a bad HTTP status code but
     * do receive a bad RC in one of the messages returned by the API
     */
    checkReturnCode(response) {
        let succeeded = true;
        const failingMessages = {};
        for (const messageID of Object.keys(response.messages)) {
            const message = response.messages[messageID];
            const HEXADECIMAL = 16;
            // if the return code on the message is not zero
            // the command did not succeed
            if (message.rc !== undefined && parseInt(message.rc, HEXADECIMAL) !== 0) {
                succeeded = false;
                failingMessages[messageID] = message;
            }
        }
        if (!succeeded) {
            this.params.response.console.error(imperative_1.TextUtils.prettyJson(response.data));
            this.params.response.console.error(imperative_1.TextUtils.prettyJson(failingMessages));
            this.params.response.data.setObj(response);
            throw new imperative_1.ImperativeError({ msg: "Encountered a non-zero return code from IMS Operations APIs", causeErrors: failingMessages });
        }
    }
}
exports.ImsBaseHandler = ImsBaseHandler;
//# sourceMappingURL=ImsBaseHandler.js.map